api.reports.v1 package — Argus-Toolbelt 1.0 documentation

# api.reports.v1 package

## Submodules

## api.reports.v1.job module

Autogenerated API

`api.reports.v1.job.` `generate`(scheduleID: int = None, planID: int = None, reportCustomerID: int = None, flags: int = None, periodStart: int = None, periodEnd: int = None, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  null (DEV)

  Return type: | `dict`
  Parameters: | scheduleID (int) – planID (int) – reportCustomerID (int) – flags (int) – periodStart (int) – periodEnd (int) –
  Returns: | {}

`api.reports.v1.job.` `get`(limit: int = None, offset: int = None, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Lists report jobs (DEV) Returns a list of matching report jobs.

  Return type: | `dict`

`api.reports.v1.job.` `search`(limit: int = None, offset: int = None, includeFlags: int = None, excludeFlags: int = None, subCriteria: list = None, id: list = None, createdByUserID: list = None, period: list = None, status: list = None, planID: list = None, scheduleID: list = None, startTimestamp: int = None, endTimestamp: int = None, sortBy: list = None, includeDeleted: bool = 'False', exclude: bool = 'False', required: bool = 'False', includeFinishedTimestamp: bool = 'False', includeCreatedTimestamp: bool = 'False', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Detailed search for report jobs (DEV) Returns a list of matching report jobs.

  Return type: | `dict`

## api.reports.v1.plan module

Autogenerated API

`api.reports.v1.plan.` `add`(setFlags: int = None, description: str = None, period: str = None, customerID: int = 0, templateID: int = 0, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Add a new report plan (DEV)

  Return type: | `dict`
  Parameters: | setFlags (int) – description (str) – Report plan description => [sw{}$-().[]“‘_/,*+#:@!?;]* period (str) – Report period customerID (int) – Customer ID (default 0) templateID (int) – Template ID (default 0)
  Raises: | AuthenticationFailedException – on 401 ValidationFailedException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 938, “limit”: 621, “responseCode”: 200, “count”: 640, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Action family measure.”, “messageTemplate”: “Month energy note quickly candidate look authority.”, “field”: “Full growth travel season.”, “parameter”: {}, “timestamp”: 773750053}], “currentPage”: 516, “size”: 90}

`api.reports.v1.plan.` `delete`(id: int, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Delete a report plan (DEV)

  Return type: | `dict`
  Parameters: | id (int) – ID of plan to delete
  Raises: | AuthenticationFailedException – on 401 ValidationFailedException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 687, “limit”: 417, “responseCode”: 200, “count”: 931, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Series discuss measure tough.”, “messageTemplate”: “Western painting difference mention security measure paper process.”, “field”: “Language but issue shake young contain.”, “parameter”: {}, “timestamp”: 1217067946}], “currentPage”: 308, “size”: 80}

`api.reports.v1.plan.` `get`(id: int, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Fetch report plan (DEV)

  Return type: | `dict`
  Parameters: | id (int) – ID of plan to fetch
  Raises: | AuthenticationFailedException – on 401 ValidationFailedException – on 412 AccessDeniedException – on 403 PlanNotFoundException – on 404
  Returns: | {“offset”: 357, “limit”: 930, “responseCode”: 200, “count”: 675, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Especially unit move citizen capital share stage herself.”, “messageTemplate”: “Customer door word save reality report.”, “field”: “Foot news contain popular.”, “parameter”: {}, “timestamp”: 831067268}], “currentPage”: 177, “size”: 766}

`api.reports.v1.plan.` `get_search`(offset: int = None, customerID: list = None, period: list = None, limit: int = 25, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Lists report plans (DEV) Returns a list of matching report plans.

  Return type: | `dict`

`api.reports.v1.plan.` `revisions`(id: int, body: str = None, limit: int = 25, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  List previous revisions for this plan (DEV)

  Return type: | `dict`
  Parameters: | id (int) – ID of plan to fetch previous revisions for body (`str`) – Offset result limit (int) – Limit output
  Raises: | AuthenticationFailedException – on 401 ValidationFailedException – on 412 AccessDeniedException – on 403 PlanNotFoundException – on 404
  Returns: | {“offset”: 148, “limit”: 39, “responseCode”: 200, “count”: 70, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Improve future see effect school short pattern meeting.”, “messageTemplate”: “Girl suffer night dream room.”, “field”: “Purpose stay hot they country option eat.”, “parameter”: {}, “timestamp”: 1389945307}], “currentPage”: 865, “size”: 140}

`api.reports.v1.plan.` `search`(limit: int = None, offset: int = None, includeFlags: int = None, excludeFlags: int = None, subCriteria: list = None, customerID: list = None, id: list = None, lastUpdatedByUserID: list = None, period: list = None, startTimestamp: int = None, endTimestamp: int = None, masterID: int = None, includeDeleted: bool = 'False', exclude: bool = 'False', required: bool = 'False', includeCreatedTimestamp: bool = 'False', includeLastUpdatedTimestamp: bool = 'False', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Lists report plans (DEV) Returns a list of matching report plans.

  Return type: | `dict`

## api.reports.v1.schedule module

Autogenerated API

`api.reports.v1.schedule.` `add`(setFlags: int = None, description: str = None, planID: int = None, schedule: str = None, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  null (DEV)

  Return type: | `dict`
  Parameters: | setFlags (int) – description (str) – Report schedule description => [sw{}$-().[]“‘_/,*+#:@!?;]* planID (int) – schedule (str) – Report schedule
  Returns: | {}

`api.reports.v1.schedule.` `delete`(id: int, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Delete a report schedule (DEV)

  Return type: | `dict`
  Parameters: | id (int) – ID of plan to delete
  Raises: | AuthenticationFailedException – on 401 ValidationFailedException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 851, “limit”: 45, “responseCode”: 200, “count”: 587, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Dinner herself should green couple.”, “messageTemplate”: “View remember look trade far listen maybe.”, “field”: “May oil pressure draw laugh or.”, “parameter”: {}, “timestamp”: 998758538}], “currentPage”: 387, “size”: 794}

`api.reports.v1.schedule.` `generate_from_schedule`(id: int, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  null (DEV)

  Return type: | `dict`
  Parameters: | id (int) –
  Returns: | {}

`api.reports.v1.schedule.` `get`(id: int, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Fetch a report schedule (DEV)

  Return type: | `dict`
  Parameters: | id (int) – ID of schedule to fetch
  Raises: | AuthenticationFailedException – on 401 ValidationFailedException – on 412 AccessDeniedException – on 403 ScheduleNotFoundException – on 404
  Returns: | {“offset”: 626, “limit”: 767, “responseCode”: 200, “count”: 963, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Listen management mother accept statement.”, “messageTemplate”: “Special sister father necessary seek.”, “field”: “Dark until include tonight Congress debate rise.”, “parameter”: {}, “timestamp”: 406436141}], “currentPage”: 885, “size”: 799}

`api.reports.v1.schedule.` `get_search`(offset: int = None, customerID: list = None, planID: list = None, limit: int = 25, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  List report schedules (DEV) Returns a list of matching report schedules.

  Return type: | `dict`

`api.reports.v1.schedule.` `search`(limit: int = None, offset: int = None, includeFlags: int = None, excludeFlags: int = None, subCriteria: list = None, customerID: list = None, id: list = None, lastUpdatedByUserID: list = None, planID: list = None, startTimestamp: int = None, endTimestamp: int = None, includeDeleted: bool = 'False', exclude: bool = 'False', required: bool = 'False', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Search report schedules (DEV) Returns a list of matching report schedules.

  Return type: | `dict`

## api.reports.v1.search module

Autogenerated API

`api.reports.v1.search.` `simplified_search_reports`(customerID: list = None, period: list = None, status: list = None, startTime: int = 0, endTime: int = 0, offset: int = 0, limit: int = 25, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  search customer reports (INTERNAL)

  Return type: | `dict`
  Parameters: | customerID (list) – Search by Customer IDs period (list) – Search by Periods status (list) – Search by Report Status startTime (int) – Search by specified start timestamp endTime (int) – Search by specified end timestamp offset (int) – Skip a number of reports limit (int) – Maximum number of reports
  Raises: | AuthenticationFailedException – on 401 ValidationFailedException – on 412 AccessDeniedException – on 403 NotFoundException – on 404
  Returns: | {“offset”: 533, “limit”: 698, “responseCode”: 200, “count”: 684, “data”: [{“id”: 199, “lastUpdatedTimestamp”: 399280622, “publishedTimestamp”: 689805426, “startTimestamp”: 1127037213, “endTimestamp”: 1215232698, “createdByUser”: {“id”: 867, “customerID”: 792, “userName”: “stephenvillarreal”, “name”: “James Graham”}, “description”: “Forget time group seek common eat main.”, “period”: “MONTH”, “status”: “NEW”}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Live she table interesting.”, “messageTemplate”: “Question sound stand.”, “field”: “Argue similar successful public seek effort.”, “parameter”: {}, “timestamp”: 1204659340}], “currentPage”: 788, “size”: 581}

## api.reports.v1.template module

Autogenerated API

`api.reports.v1.template.` `add`(name: str = None, data: str = None, text: str = None, mimeType: str = None, accessMode: str = 'roleBased', lockRequestTime: int = 300000, inheritExplicitPermissions: bool = 'True', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Add a report template (DEV)

  Return type: | `dict`
  Parameters: | name (str) – Name of new document => Sanitize by regex [a-zA-Z0-9ÅåØøÆæ_-. ]* data (str) – Base64 encoded document content formatted according to the given MIME type. It is required if ‘text’ parameter is not defined text (str) – Plain text document content. It is required if the ‘data’ parameter is not defined mimeType (str) – MIME type of document content accessMode (str) – General access mode of new document (default roleBased) lockRequestTime (int) – Specify how long the document should be locked (default 300000) inheritExplicitPermissions (bool) – Inherit explicit permissions from parent folder (default true)
  Raises: | AuthenticationFailedException – on 401 ValidationFailedException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 462, “limit”: 249, “responseCode”: 200, “count”: 979, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Act rule form sit.”, “messageTemplate”: “Security citizen cover area scene need network.”, “field”: “Well forward help medical order none pattern.”, “parameter”: {}, “timestamp”: 1452116626}], “currentPage”: 49, “size”: 811}

`api.reports.v1.template.` `get_template`(id: int, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Fetch report template (DEV) Returns the specified report template

  Return type: | `dict`

`api.reports.v1.template.` `list_templates`(offset: int = None, customerID: list = None, limit: int = 25, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  List report templates (DEV) Returns a list of matching report templates.

  Return type: | `dict`

`api.reports.v1.template.` `search_templates`(limit: int = None, offset: int = None, subCriteria: list = None, customerID: list = None, id: list = None, userID: list = None, userFieldStrategy: list = None, accessMode: list = None, state: list = None, startTimestamp: int = None, endTimestamp: int = None, timeFieldStrategy: list = None, keywords: list = None, keywordFieldStrategy: list = None, labels: list = None, folderID: list = None, sortBy: list = None, includeFlags: list = None, excludeFlags: list = None, timeMatchStrategy: str = 'any', keywordMatchStrategy: str = 'any', recursive: bool = 'True', includeDeleted: bool = 'False', exclude: bool = 'False', required: bool = 'False', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Search report templates (DEV) Returns a list of matching report templates.

  Return type: | `dict`

`api.reports.v1.template.` `update`(id: int, name: str = None, mimeType: str = None, data: str = None, text: str = None, lockRequestTime: int = 300000, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Update a report template (DEV)

  Return type: | `dict`
  Parameters: | id (int) – ID of template to update name (str) – If set change document name => Sanitize by regex [a-zA-Z0-9ÅåØøÆæ_-. ]* mimeType (str) – If set change document MIME type data (str) – Base64 encoded document content formatted according to the given MIME type. If set change document content text (str) – Plain text document content. If set change document content lockRequestTime (int) – Specify how long the document should be locked (default 300000)
  Raises: | AuthenticationFailedException – on 401 ValidationFailedException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 633, “limit”: 468, “responseCode”: 200, “count”: 175, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Dream himself end she.”, “messageTemplate”: “Rather ability again energy wind memory interview.”, “field”: “Assume establish significant course woman.”, “parameter”: {}, “timestamp”: 1076660174}], “currentPage”: 812, “size”: 609}

## Module contents